@@ -1,6 +1,6 @@
 package App::JobLog::Command::configure;
 BEGIN {
-  $App::JobLog::Command::configure::VERSION = '1.010';
+  $App::JobLog::Command::configure::VERSION = '1.011';
 }
 
 # ABSTRACT: examine or modify App::JobLog configuration
@@ -16,6 +16,7 @@ use App::JobLog::Config qw(
   precision
   start_pay_period
   sunday_begins_week
+  time_zone
   workdays
   DAYS
   HIDABLE_COLUMNS
@@ -25,6 +26,7 @@ use App::JobLog::Config qw(
   PERIOD
   PRECISION
   SUNDAY_BEGINS_WEEK
+  TIME_ZONE
   WORKDAYS
 );
 use autouse 'App::JobLog::TimeGrammar' => qw(parse);
@@ -93,6 +95,10 @@ sub execute {
         $value = hidden_columns($value);
         say "hidden columns: $value";
     }
+    if ( defined $opt->time_zone ) {
+        my $value = time_zone( $opt->time_zone );
+        say "time zone is now $value";
+    }
 }
 
 sub usage_desc { '%c ' . __PACKAGE__->name . ' %o' }
@@ -114,6 +120,10 @@ sub options {
               . 'pay period boundaries will be calculated based on this date and the pay period length; '
               . 'e.g., --start-pay-period="June 14, 1912"'
         ],
+        [
+            'time-zone=s',
+            'time zone used in calendar calculations; default is ' . TIME_ZONE
+        ],
         [
             'sunday-begins-week=s',
             'whether Sundays should be regarded as the first day in the week; '
@@ -151,7 +161,7 @@ sub options {
               . App::JobLog::Command::summary->name
               . ' command; '
               . 'available options are: '
-              . join( ', ', map { "'$_'" } @{HIDABLE_COLUMNS()} ) . '; '
+              . join( ', ', map { "'$_'" } @{ HIDABLE_COLUMNS() } ) . '; '
               . "default is '@{[NONE_COLUMN]}'; "
               . 'multiple columns may be specified'
         ],
@@ -173,6 +183,7 @@ sub _list_params {
       pay_period_length
       start_pay_period
       sunday_begins_week
+      time_zone
       workdays
     );
     my %booleans = map { $_ => 1 } qw(
@@ -221,7 +232,7 @@ sub validate {
         }
     }
     if ( defined $opt->hidden_columns ) {
-        my %h = map { $_ => 1 } @{HIDABLE_COLUMNS()};
+        my %h = map { $_ => 1 } @{ HIDABLE_COLUMNS() };
         my ( $found_none, $found_something ) = ( 0, 0 );
         for my $c ( @{ $opt->hidden_columns } ) {
             my $col = lc $c;
@@ -251,7 +262,7 @@ App::JobLog::Command::configure - examine or modify App::JobLog configuration
 
 =head1 VERSION
 
-version 1.010
+version 1.011
 
 =head1 SYNOPSIS
 
@@ -265,6 +276,8 @@ version 1.010
  	                          period boundaries will be calculated based
  	                          on this date and the pay period length;
  	                          e.g., --start-pay-period="June 14, 1912"
+	--time-zone               time zone used in calendar calculations;
+	                          default is local
  	--sunday-begins-week      whether Sundays should be regarded as the
  	                          first day in the week; the alternative is
  	                          Monday; default is TRUE
@@ -298,6 +311,7 @@ version 1.010
  precision                           1
  start pay period           2009-01-11
  sunday begins week               true
+ time zone                       local
  workdays                        MTWHF
  houghton@NorthernSpy:~$ job configure --precision 2
  precision set to 2
@@ -310,6 +324,7 @@ version 1.010
  precision                           2
  start pay period           2009-01-11
  sunday begins week               true
+ time zone                       local
  workdays                        MTWHF
 
 =head1 DESCRIPTION
@@ -376,6 +391,11 @@ Another convention is to regard Sunday as the first day of the week. This is sig
 meaning of phrases such as I<this week> and I<March 1 until the end of the week>. Use this parameter to choose
 your preferred interpretation of such phrases.
 
+=item time zone
+
+This is the time zone used for converting the system time to the time of the day. Most likely you will not need
+to set this parameter, but go here if your times look funny.
+
 =item workdays
 
 L<App::JobLog> needs to know which days you are expected to work in order to determine when to assign vacation
